***************************
*** RDC Regression analysis
****************************

**** 2/18/2013


**************************************************************
**** Conduct Specifications/Tests that rely on full sample
***************************************************************

clear



local dir="Z:/Data"

local dirtemp="Z:/Data/OutTemp"

local dirfin="Z:/Data/Output030613"

cd `dirtemp'

set mem 1g

log using `dirfin'/nhis36fullrev , replace

set more off

use `dir'/data.dta

***adjust missing observations

*** Drop Puerto Rico

drop if state==72






local samplevarlist "age_p medicare schip ihs military otherpub othergov medicaid hicostr1 hicostr2 plnwrkn1 plnwrkn2 plnmgd1 plnmgd2 srvy_yr hhx fmx hiempof  hcspfyr rat_cat"

*** drop old family members (age>=65) and children

keep if age_p<65 & age_p>=18 & age_p!=.

*** intrinsic interest in the uninsured and the privately insured
*** let's drop persons that benefit from other sources of insurance (other than Medicaid) such as:
*** medicare , private, schip, ihs (indian health service), milcare (Military health care coverage), othpub , othgov

keep if medicare>2 & schip>2 & ihs>1 & military>2 & otherpub>2 & othergov>2 & medicaid>2

** group vs. non-group market

*** hiempof=1 means that employer offers health insurance
*** Ass: whenever one family member has access to HI through empoyer, the all others have so too

by srvy_yr hhx fmx, sort: egen group_market=min(hiempof)

replace group_market=0 if group_market!=1

*** Drop individuals that purchase HI directly even though they are in the group market
*** first identfy major plan: default plan 1. looking at the data the vast majority provides info on plan 1 and not on plan 2
*** important characteristics: premium, how obtained, plan type

replace hicostr1=. if hicostr1==99997 | hicostr1==99999
replace hicostr2=. if hicostr2==99997 | hicostr2==99999

gen premium=hicostr1
replace premium=hicostr2 if hicostr1==. & hicostr2!=.

gen obtained=plnwrkn1
replace obtained=plnwrkn2 if hicostr1==. & hicostr2!=.

gen plantype=plnmgd1
replace plantype=plnmgd2 if hicostr1==. & hicostr2!=.


*** now back to individuals that purchase HI directly even though they are in the group market. It's a very small number of observations, so to be
*** consistent let's drop the entire family

gen ind=0
replace ind=1 if group_market==1 & (obtained==5 | obtained==6 | obtained==7 | obtained==8) 

by srvy_yr hhx fmx, sort: egen ind_fam=max(ind)

drop if ind_fam==1

drop ind ind_fam

***********************************************

gen fpl300more=.

**** income<FPL

replace fpl300more=0 if rat_cat<10 | rat_cat==15 | rat_cat==16

replace fpl300more=1 if (rat_cat>9 & rat_cat<15) |  rat_cat==17 |  rat_cat==18 


gen fpl150more=.

**** income<FPL

replace fpl150more=0 if rat_cat<6 | rat_cat==15 | rat_cat==16

replace fpl150more=1 if (rat_cat>6 & rat_cat<15) |  rat_cat==17 |  rat_cat==18 



*** done with group vs. non-group market distinction

*** generate coverage estimates at the state-year-level, using personal weights

**** two coverage measures

*** upper bound, including Medicaid people (full crowd out)
*** lower bound, excluding all Medicaid people (no crowd out)

gen ins=0

replace ins=1 if notcov==2  

*** drop if coverage status indetermined

drop if notcov==9

**** prepare level-graphs 


**** insurance coverage: 300%

gen hmo=0

replace hmo=1 if plantype==1


save `dir'/nhis_prelim63.dta, replace


***************************************************
*** Overview State Obs
***************************************************

gen obsgroup150=0
replace obsgroup150=1 if group_market==1 & fpl150more==1 & group_market!=. & fpl150more!=. 

gen obsnongroup150=0 
replace obsnongroup150=1 if group_market==0 & fpl150more==1 & group_market!=. & fpl150more!=. 

gen obsgroup300=0
replace obsgroup300=1 if group_market==1 & fpl300more==1 & group_market!=. & fpl300more!=. 

gen obsnongroup300=0
replace obsnongroup300=1 if group_market==0 & fpl300more==1 & group_market!=. & fpl300more!=. 


collapse (sum) obsgroup150 obsnongroup150 obsgroup300 obsnongroup300, by(state srvy_yr) 

gen year=srvy_yr

drop srvy_yr 

cd `dirfin'

label variable obsgroup150 "Obs Group 150"
label variable obsnongroup150 "Obs NonGroup 150"
label variable obsgroup300 "Obs Group 300"
label variable obsnongroup300 "Obs NonGroup 300"
label variable year "Year"
label variable state "State"

export excel using observations-all.xls, replace firstrow(varlabels)


cd `dirtemp'


clear

use `dir'/nhis_prelim63.dta

************************************************
**** Reform period
************************************************

gen period=0

replace period=1 if srvy_yr==2006 | srvy_yr==2007

replace period=2 if srvy_yr>2007


local varlist "ins hmo age"

svyset [pw=wtfa], strata(strat_p) psu(psu_p)


  foreach var of local varlist {




svy, subpop(if MA==0 & group_market==0 & fpl300more==1) : mean `var', over(srvy_yr) 
estimates save `var'300_nma_ngm, replace
svy, subpop(if MA==1 & group_market==0 & fpl300more==1) : mean `var', over(srvy_yr) 
estimates save `var'300_ma_ngm, replace
svy, subpop(if MA==0 & group_market==1 & fpl300more==1) : mean `var', over(srvy_yr) 
estimates save `var'300_nma_gm , replace
svy, subpop(if MA==1 & group_market==1 & fpl300more==1) : mean `var', over(srvy_yr) 
estimates save `var'300_ma_gm , replace

**** insurance coverage: 150%




svy, subpop(if MA==0 & group_market==0 & fpl150more==1) : mean `var', over(srvy_yr) 
estimates save `var'150_nma_ngm, replace
svy, subpop(if MA==1 & group_market==0 & fpl150more==1) : mean `var', over(srvy_yr) 
estimates save `var'150_ma_ngm, replace
svy, subpop(if MA==0 & group_market==1 & fpl150more==1) : mean `var', over(srvy_yr) 
estimates save `var'150_nma_gm , replace
svy, subpop(if MA==1 & group_market==1 & fpl150more==1) : mean `var', over(srvy_yr) 
estimates save `var'150_ma_gm , replace



}

***

*** Means State/Period

local varliststate "ins hmo age state"

  foreach var of local varliststate {
  

svy, subpop(if period==2 & group_market==0 & fpl300more==1) : mean `var', over(state) 
estimates save `var'300_post, replace
svy, subpop(if period==1 & group_market==0 & fpl300more==1) : mean `var', over(state) 
estimates save `var'300_ref, replace
svy, subpop(if period==0 & group_market==0 & fpl300more==1) : mean `var', over(state) 
estimates save `var'300_pre , replace

svy, subpop(if period==2 & group_market==0 & fpl150more==1) : mean `var', over(state) 
estimates save `var'150_post, replace
svy, subpop(if period==1 & group_market==0 & fpl150more==1) : mean `var', over(state) 
estimates save `var'150_ref, replace
svy, subpop(if period==0 & group_market==0 & fpl150more==1) : mean `var', over(state) 
estimates save `var'150_pre , replace


}



*** Means State/Year

  foreach var of local varliststate {
  

svy, subpop(if srvy_yr==2010 & group_market==0 & fpl300more==1) : mean `var', over(state) 
estimates save `var'300_10, replace
svy, subpop(if srvy_yr==2009 & group_market==0 & fpl300more==1) : mean `var', over(state) 
estimates save `var'300_9, replace
svy, subpop(if srvy_yr==2008 & group_market==0 & fpl300more==1) : mean `var', over(state) 
estimates save `var'300_8, replace
svy, subpop(if srvy_yr==2007 & group_market==0 & fpl300more==1) : mean `var', over(state) 
estimates save `var'300_7, replace
svy, subpop(if srvy_yr==2006 & group_market==0 & fpl300more==1) : mean `var', over(state) 
estimates save `var'300_6, replace
svy, subpop(if srvy_yr==2005 & group_market==0 & fpl300more==1) : mean `var', over(state) 
estimates save `var'300_5, replace
svy, subpop(if srvy_yr==2004 & group_market==0 & fpl300more==1) : mean `var', over(state) 
estimates save `var'300_4, replace

svy, subpop(if srvy_yr==2010 & group_market==0 & fpl150more==1) : mean `var', over(state) 
estimates save `var'150_10, replace
svy, subpop(if srvy_yr==2009 & group_market==0 & fpl150more==1) : mean `var', over(state) 
estimates save `var'150_9, replace
svy, subpop(if srvy_yr==2008 & group_market==0 & fpl150more==1) : mean `var', over(state) 
estimates save `var'150_8, replace
svy, subpop(if srvy_yr==2007 & group_market==0 & fpl150more==1) : mean `var', over(state) 
estimates save `var'150_7, replace
svy, subpop(if srvy_yr==2006 & group_market==0 & fpl150more==1) : mean `var', over(state) 
estimates save `var'150_6, replace
svy, subpop(if srvy_yr==2005 & group_market==0 & fpl150more==1) : mean `var', over(state) 
estimates save `var'150_5, replace
svy, subpop(if srvy_yr==2004 & group_market==0 & fpl150more==1) : mean `var', over(state) 
estimates save `var'150_4, replace


}


clear



local varlist "ins300 ins150 hmo300 hmo150 age300 age150"  



foreach var of local varlist {

estimates use `var'_nma_ngm
matrix define ivmat=e(b)
matrix ivvar=[ivmat[1,1..7]]'
matrix vce=get(VCE)
matrix ivvariance=vecdiag(vce)
matrix ivdiag=[ivvariance[1,1..7]]'
svmat ivvar
svmat ivdiag
rename ivvar `var'_nma_ngm
gen seivdiag=sqrt(ivdiag)
gen `var'_nma_ngm_lb=`var'_nma_ngm-seivdiag*1.96
gen `var'_nma_ngm_ub=`var'_nma_ngm+seivdiag*1.96
drop ivdiag seivdiag

estimates use `var'_nma_gm
matrix define ivmat=e(b)
matrix ivvar=[ivmat[1,1..7]]'
matrix vce=get(VCE)
matrix ivvariance=vecdiag(vce)
matrix ivdiag=[ivvariance[1,1..7]]'
svmat ivvar
svmat ivdiag
rename ivvar `var'_nma_gm
gen seivdiag=sqrt(ivdiag)
gen `var'_nma_gm_lb=`var'_nma_gm-seivdiag*1.96
gen `var'_nma_gm_ub=`var'_nma_gm+seivdiag*1.96
drop ivdiag seivdiag

estimates use `var'_ma_ngm
matrix define ivmat=e(b)
matrix ivvar=[ivmat[1,1..7]]'
matrix vce=get(VCE)
matrix ivvariance=vecdiag(vce)
matrix ivdiag=[ivvariance[1,1..7]]'
svmat ivvar
svmat ivdiag
rename ivvar `var'_ma_ngm
gen seivdiag=sqrt(ivdiag)
gen `var'_ma_ngm_lb=`var'_ma_ngm-seivdiag*1.96
gen `var'_ma_ngm_ub=`var'_ma_ngm+seivdiag*1.96
drop ivdiag seivdiag

estimates use `var'_ma_gm
matrix define ivmat=e(b)
matrix ivvar=[ivmat[1,1..7]]'
matrix vce=get(VCE)
matrix ivvariance=vecdiag(vce)
matrix ivdiag=[ivvariance[1,1..7]]'
svmat ivvar
svmat ivdiag
rename ivvar `var'_ma_gm
gen seivdiag=sqrt(ivdiag)
gen `var'_ma_gm_lb=`var'_ma_gm-seivdiag*1.96
gen `var'_ma_gm_ub=`var'_ma_gm+seivdiag*1.96
drop ivdiag seivdiag


}



********************************************************************
**** Level Graphs
********************************************************************



**** level graphs


***********************

cd `dirfin'


gen srvy_yr=_n+2003



foreach var of local varlist {


local file "`var'"




*** group market

   	scatter `var'_nma_gm `var'_nma_gm_lb `var'_nma_gm_ub `var'_ma_gm `var'_ma_gm_lb `var'_ma_gm_ub srvy_yr , connect(l l l l l l) ///
	xline(2006) xline(2007) /// 
	xlabel(2004 "2004"  2006 "2006" 2008 "2008" 2010 "2010") ///
	msize(small vtiny vtiny small vtiny vtiny) ///
	lpattern(solid solid solid solid solid solid) ///
	lwidth(medthick thin thin medthick thin thin) ///
	lcolor(gs0 gs8 gs8 blue gs8 gs8) ///
	mcolor(gs0 gs8 gs8 blue gs8 gs8) ///
	msymbol(O O O D D D) ///
	legend(order(1 4)) ///
 	xtitle("Year") ///
	title("Group Market") ///
	graphregion(color(white)) ///
	legend(rows(1) label(1 Non-MA) label(4 MA)) ///
	saving(`file'_group.gph, replace)

*** nongroup market

   	scatter `var'_nma_ngm `var'_nma_ngm_lb `var'_nma_ngm_ub `var'_ma_ngm `var'_ma_ngm_lb `var'_ma_ngm_ub srvy_yr , connect(l l l l l l) ///
	xline(2006) xline(2007) /// 	
	xlabel(2004 "2004"  2006 "2006" 2008 "2008" 2010 "2010") ///
	msize(small vtiny vtiny small vtiny vtiny) ///
	lpattern(solid solid solid solid solid solid) ///
	lwidth(medthick thin thin medthick thin thin) ///
	lcolor(gs0 gs8 gs8 blue gs8 gs8) ///
	mcolor(gs0 gs8 gs8 blue gs8 gs8) ///
	msymbol(O O O D D D) ///
	legend(order(1 4)) ///
 	xtitle("Year") ///
	title("Individual Market") ///
	graphregion(color(white)) ///
	legend(rows(1) label(1 Non-MA) label(4 MA)) ///
	saving(`file'_nongroup.gph, replace)
	
graph combine `file'_group.gph `file'_nongroup.gph , ycommon cols(2) xsize(11)  ysize(7.5) graphregion(color(white)) 
graph export `file'_all.ps, replace logo(off) orientation(landscape) lmargin(0) tmargin(0.5)
capture ! ps2pdf `file'_all.ps `file'_all.pdf

}



********
** Table for post-reform realizations 
******************

clear

cd `dirtemp'

local varlist "ins300 ins150 hmo300 hmo150 age300 age150 state300"  



foreach var of local varlist {

estimates use `var'_post
matrix define ivmat=e(b)
matrix ivvar=[ivmat[1,1..51]]'
matrix vce=get(VCE)
matrix ivvariance=vecdiag(vce)
matrix ivdiag=[ivvariance[1,1..51]]'
svmat ivvar
svmat ivdiag
rename ivvar `var'_post
gen seivdiag=sqrt(ivdiag)
drop ivdiag seivdiag

estimates use `var'_ref
matrix define ivmat=e(b)
matrix ivvar=[ivmat[1,1..51]]'
matrix vce=get(VCE)
matrix ivvariance=vecdiag(vce)
matrix ivdiag=[ivvariance[1,1..51]]'
svmat ivvar
svmat ivdiag
rename ivvar `var'_ref
gen seivdiag=sqrt(ivdiag)
drop ivdiag seivdiag

estimates use `var'_pre
matrix define ivmat=e(b)
matrix ivvar=[ivmat[1,1..51]]'
matrix vce=get(VCE)
matrix ivvariance=vecdiag(vce)
matrix ivdiag=[ivvariance[1,1..51]]'
svmat ivvar
svmat ivdiag
rename ivvar `var'_pre
gen seivdiag=sqrt(ivdiag)
drop ivdiag seivdiag

}


*****
gen number=_n

sort number

merge number using `dir'/state_number.dta

**** merge state



**** label variables

label variable ins300_post "Insurance 300%: Post"
label variable ins300_ref "Insurance 300%: Reform"
label variable ins300_pre "Insurance 300%: Pre"

label variable ins150_post "Insurance 150%: Post"
label variable ins150_ref "Insurance 150%: Reform"
label variable ins150_pre "Insurance 150%: Pre"

label variable hmo300_post "HMO 300%: Post"
label variable hmo300_ref "HMO 300%: Reform"
label variable hmo300_pre "HMO 300%: Pre"

label variable hmo150_post "HMO 150%: Post"
label variable hmo150_ref "HMO 150%: Reform"
label variable hmo150_pre "HMO 150%: Pre"

label variable age300_post "Age 300%: Post"
label variable age300_ref "Age 300%: Reform"
label variable age300_pre "Age 300%: Pre"

label variable age150_post "Age 150%: Post"
label variable age150_ref "Age 150%: Reform"
label variable age150_pre "Age 150%: Pre"

label variable state300_post "State 300"

drop state300_ref state300_pre

cd `dirfin'

export excel using state-period-mean.xls, replace firstrow(varlabels)

*** If excel does not work

*** Insurance

eststo clear

eststo: estpost tabstat ins300_post ins300_ref ins300_pre ins150_post ins150_ref ins150_pre , stat(mean) by(state)

esttab using ins.tex, cells("ins300_post(fmt(4) label(300 Post)) ins300_ref(fmt(4) label(300 Ref)) ins300_pre(fmt(4) label(300 Pre)) ins150_post(fmt(4) label(150 Post)) ins150_ref(fmt(4) label(150 Ref)) ins150_pre(fmt(4) label(150 Pre))") label nodepvar nonumber unstack replace

eststo clear

*** HMO

eststo: estpost tabstat hmo300_post hmo300_ref hmo300_pre hmo150_post hmo150_ref hmo150_pre , stat(mean) by(state)

esttab using hmo.tex, cells("hmo300_post(fmt(4) label(300 Post)) hmo300_ref(fmt(4) label(300 Ref)) hmo300_pre(fmt(4) label(300 Pre)) hmo150_post(fmt(4) label(150 Post)) hmo150_ref(fmt(4) label(150 Ref)) hmo150_pre(fmt(4) label(150 Pre))") label nodepvar nonumber unstack replace

*** Age

eststo clear

eststo: estpost tabstat age300_post age300_ref age300_pre age150_post age150_ref age150_pre , stat(mean) by(state)

esttab using age.tex, cells("age300_post(fmt(4) label(300 Post)) age300_ref(fmt(4) label(300 Ref)) age300_pre(fmt(4) label(300 Pre)) age150_post(fmt(4) label(150 Post)) age150_ref(fmt(4) label(150 Ref)) age150_pre(fmt(4) label(150 Pre))") label nodepvar nonumber unstack replace

eststo clear


cd `dirtemp'


clear


******************************
*** For each year
*****************************
local yearlist ""4" "5" "6" "7" "8" "9" "10"" 

local incomecutoffs ""150" "300"" 

foreach yr of local yearlist { 

foreach inc of local incomecutoffs {

local varlist "ins hmo age state"    

foreach var of local varlist {
estimates use `var'`inc'_`yr'
matrix define ivmat=e(b)
matrix ivvar=[ivmat[1,1...]]'
svmat ivvar
rename ivvar `var'`inc'_`yr'

}


rename state`inc'_`yr' state

sort state

save sumdata`inc'_`yr'.dta, replace


clear
}
}
*****
*************
*** Merge all data
*****
 use sumdata150_4.dta
 
 merge state using sumdata300_4.dta
 
 drop _merge
 
local yearlistshort ""5" "6" "7" "8" "9" "10"" 
 
local incomecutoffs ""150" "300""

foreach yr of local yearlistshort { 

foreach inc of local incomecutoffs {

sort state 

merge state using sumdata`inc'_`yr'.dta

drop _merge

}
}
****

reshape long ins150_ ins300_ age150_ age300_ hmo150_ hmo300_ ,   i(state) j(srvy_yr)

rename ins150_ ins150

rename ins300_ ins300

rename age150_ age150

rename age300_ age300

rename hmo150_ hmo150

rename hmo300_ hmo300

replace srvy_yr=srvy_yr+2000

save sumdata0410.dta, replace


keep ins150 ins300 srvy_yr state


label variable ins150 "Insurance 150%"
label variable ins300 "Insurance 300%"
label variable state "Fips"
label variable srvy_yr "Year"


cd `dirfin'

export excel using coverage-all.xls, replace firstrow(varlabels)


cd `dirtemp'

*** Generate Weights

clear

use `dir'/nhis_prelim63.dta



keep if fpl300more==1 & group_market==0

gen obs=1

collapse (sum) obs, by(state srvy_yr)

rename obs obs300

sort state srvy_yr 

save weights300.dta, replace


clear

use `dir'/nhis_prelim63.dta

*** Generate Weights


keep if fpl150more==1 & group_market==0

gen obs=1

collapse (sum) obs, by(state srvy_yr)

rename obs obs150

sort state srvy_yr 

save weights150.dta, replace

clear



cd `dirtemp'

**************************************************
*** Regression based evidence
**************************************************

use sumdata0410.dta

sort state srvy_yr


**** Add weights

merge state srvy_yr using `dirtemp'/weights300.dta

tab _merge

keep if _merge!=2

drop _merge


sort state srvy_yr

**** Add weights

merge state srvy_yr using `dirtemp'/weights150.dta

tab _merge

keep if _merge!=2

drop _merge



*************************************************************************************************
***** Prepare Regresions
************************************************************************************************
cd `dirfin'


rename srvy_yr yearold

gen year=yearold-2007

gen MA=0

replace MA=1 if state==25

gen MAyear=MA*year

gen during=0
replace during=1 if yearold==2006 | yearold==2007

gen after=0
replace after=1 if yearold>2007

gen MAduring=during*MA
gen MAafter=after*MA

gen during_year=during*year
gen after_year=after*year

gen during_MA_year=MA*during*year
gen after_MA_year=MA*after*year


label variable MAafter "$\gamma^k$   MA*After"
label variable MAduring "$\rho_1^k$   MA*During"
label variable MA "$\rho_2^k$  MA"
label variable after "$\rho_3^k$   After"
label variable during "$\rho_4^k$   During"
label variable after_MA_year "$\rho_5^k$ MA*After*Year"
label variable during_MA_year "$\rho_6^k$ MA*During*Year"
label variable MAyear "$\rho_7^k$   MA*Year"
label variable after_year "$\rho_8^k$ After*Year"
label variable during_year "$\rho_9^k$ During*Year"
label variable year "$\rho_{10}^k$ Year"


local preposttrends_all "MAafter MAduring MA after during after_MA_year during_MA_year MAyear after_year during_year year"

local preposttrends "MAafter MAduring MA after during MAyear year"

local preposttrends_parsi "MAafter MAduring MA after during"


**** 150-percent-DID

*** Full Spec

reg hmo150 `preposttrends_all' [aweight=obs150], cluster(state)
eststo hmoweight150

reg ins150 `preposttrends_all' [aweight=obs150], cluster(state)
eststo insweight150

reg age150 `preposttrends_all' [aweight=obs150], cluster(state)
eststo ageweight150

reg hmo150 `preposttrends_all', cluster(state)
eststo hmo150

reg ins150 `preposttrends_all' , cluster(state)
eststo ins150

reg age150 `preposttrends_all' , cluster(state)
eststo age150

#delimit ;
esttab  insweight150 hmoweight150 ageweight150 ins150 hmo150 age150 using did-all-150.tex , label se star(* 0.10 ** 0.05 *** 0.01) 
mtitles("Coverage: W" "HMO: W" "Age: W" "Coverage" "HMO" "Age") varlabels(_cons "$\rho_{11}^k$   Constant")  
addnotes(" \parbox[t]{10cm}{Standard errors are clustered at the state level. W specifications are weighted by the number of  observations at the state-year level.}")
replace ;

#delimit cr

eststo clear

*** Full Spec

reg hmo150 `preposttrends' [aweight=obs150], cluster(state)
eststo hmoweight150

reg ins150 `preposttrends' [aweight=obs150], cluster(state)
eststo insweight150

reg age150 `preposttrends' [aweight=obs150], cluster(state)
eststo ageweight150

reg hmo150 `preposttrends', cluster(state)
eststo hmo150

reg ins150 `preposttrends' , cluster(state)
eststo ins150

reg age150 `preposttrends' , cluster(state)
eststo age150

#delimit ;
esttab  insweight150 hmoweight150 ageweight150 ins150 hmo150 age150 using did-150.tex , label se star(* 0.10 ** 0.05 *** 0.01) 
mtitles("Coverage: W" "HMO: W" "Age: W" "Coverage" "HMO" "Age") varlabels(_cons "$\rho_{11}^k$   Constant")  
addnotes(" \parbox[t]{10cm}{Standard errors are clustered at the state level. W specifications are weighted by the number of  observations at the state-year level.}")
replace ;

#delimit cr


eststo clear

*** Full Spec

reg hmo150 `preposttrends_parsi' [aweight=obs150], cluster(state)
eststo hmoweight150

reg ins150 `preposttrends_parsi' [aweight=obs150], cluster(state)
eststo insweight150

reg age150 `preposttrends_parsi' [aweight=obs150], cluster(state)
eststo ageweight150

reg hmo150 `preposttrends_parsi', cluster(state)
eststo hmo150

reg ins150 `preposttrends_parsi' , cluster(state)
eststo ins150

reg age150 `preposttrends_parsi' , cluster(state)
eststo age150

#delimit ;
esttab  insweight150 hmoweight150 ageweight150 ins150 hmo150 age150 using did-parsi-150.tex , label se star(* 0.10 ** 0.05 *** 0.01) 
mtitles("Coverage: W" "HMO: W" "Age: W" "Coverage" "HMO" "Age") varlabels(_cons "$\rho_{11}^k$   Constant")  
addnotes(" \parbox[t]{10cm}{Standard errors are clustered at the state level. W specifications are weighted by the number of  observations at the state-year level.}")
replace ;

#delimit cr

eststo clear


*******************************************************************************************
**** 300-percent-DID
*******************************************************************************************

*** Full Spec

reg hmo300 `preposttrends_all' [aweight=obs300], cluster(state)
eststo hmoweight300

reg ins300 `preposttrends_all' [aweight=obs300], cluster(state)
eststo insweight300

reg age300 `preposttrends_all' [aweight=obs300], cluster(state)
eststo ageweight300

reg hmo300 `preposttrends_all', cluster(state)
eststo hmo300

reg ins300 `preposttrends_all' , cluster(state)
eststo ins300

reg age300 `preposttrends_all' , cluster(state)
eststo age300

#delimit ;
esttab  insweight300 hmoweight300 ageweight300 ins300 hmo300 age300 using did-all-300.tex , label se star(* 0.10 ** 0.05 *** 0.01) 
mtitles("Coverage: W" "HMO: W" "Age: W" "Coverage" "HMO" "Age") varlabels(_cons "$\rho_{11}^k$   Constant")  
addnotes(" \parbox[t]{10cm}{Standard errors are clustered at the state level. W specifications are weighted by the number of  observations at the state-year level.}")
replace ;

#delimit cr

eststo clear

*** Full Spec

reg hmo300 `preposttrends' [aweight=obs300], cluster(state)
eststo hmoweight300

reg ins300 `preposttrends' [aweight=obs300], cluster(state)
eststo insweight300

reg age300 `preposttrends' [aweight=obs300], cluster(state)
eststo ageweight300

reg hmo300 `preposttrends', cluster(state)
eststo hmo300

reg ins300 `preposttrends' , cluster(state)
eststo ins300

reg age300 `preposttrends' , cluster(state)
eststo age300

#delimit ;
esttab  insweight300 hmoweight300 ageweight300 ins300 hmo300 age300 using did-300.tex , label se star(* 0.10 ** 0.05 *** 0.01) 
mtitles("Coverage: W" "HMO: W" "Age: W" "Coverage" "HMO" "Age") varlabels(_cons "$\rho_{11}^k$   Constant")  
addnotes(" \parbox[t]{10cm}{Standard errors are clustered at the state level. W specifications are weighted by the number of  observations at the state-year level.}")
replace ;

#delimit cr


eststo clear

*** Full Spec

reg hmo300 `preposttrends_parsi' [aweight=obs300], cluster(state)
eststo hmoweight300

reg ins300 `preposttrends_parsi' [aweight=obs300], cluster(state)
eststo insweight300

reg age300 `preposttrends_parsi' [aweight=obs300], cluster(state)
eststo ageweight300

reg hmo300 `preposttrends_parsi', cluster(state)
eststo hmo300

reg ins300 `preposttrends_parsi' , cluster(state)
eststo ins300

reg age300 `preposttrends_parsi' , cluster(state)
eststo age300

#delimit ;
esttab  insweight300 hmoweight300 ageweight300 ins300 hmo300 age300 using did-parsi-300.tex , label se star(* 0.10 ** 0.05 *** 0.01) 
mtitles("Coverage: W" "HMO: W" "Age: W" "Coverage" "HMO" "Age") varlabels(_cons "$\rho_{11}^k$   Constant")  
addnotes(" \parbox[t]{10cm}{Standard errors are clustered at the state level. W specifications are weighted by the number of  observations at the state-year level.}")
replace ;

#delimit cr


eststo clear

clear

log close
