*******************************************************************************
****** This do file calculates the point estimates of the DID analysis which are presented
****** in the main regression table and the regression table with emephasis on guranteed issue states
****** located in the roibustness check section.
*******************************************************************************


clear

*log using pointestimates.txt, replace

clear

use Data\Compiled\datasnl-final.dta


gen MA_GI=0 

replace MA_GI=1 if state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 


encode state, gen(stateid)



**** Normalize year to 2007

gen yearold=year

replace year=year-2007


sort state year


*** demean

gen prem_ind_res=.


levelsof stateid, local(stateidlist)




 foreach s of local stateidlist {
 quietly sum prem_per_year_ind if stateid==`s' & yearold<2006
 
 replace prem_ind_res=prem_per_year_ind-r(mean) if stateid==`s'
 
}
***


sort state year


gen lgac=log(prov_health_serv_incur_ind_year)

gen lgprem=log(prem_per_year_ind)


gen mem_mo_ind_rel=.

**** For all States

levelsof state, local(levels) 

foreach l of local levels {

quietly sum mem_mo_ind if yearold>2007 & yearold<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*insurance300post if state=="`l'" 


}
***

**** Adjust Other States if estimate exceeds 120%



by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2


**** Merge Abadie Weights

gen statenr=stateid

merge m:1 statenr using Data\Compiled\abadieweights.dta

gen MAduring=0
replace MAduring=1 if MA==1 & (yearold==2006 | yearold==2007)

gen MAafter=0
replace MAafter=1 if MA==1 & yearold>2007


*** replace abadie weight from Missing to 1 for Massachusetts 
*** (the magnitude has no effect on estimates but needs to be nonmissing)

replace wallall2=1 if MA==1
replace wallgi2=1 if MA==1




quietly tab yearold, gen(yearfe_)


***** All

gen during=0

replace during=1 if yearold==2006 | yearold==2007


gen after=0

replace after=1 if yearold>2007



**** Lg AC (baseline weights)


quietly reg lgac MAafter MAduring MA after during  [aw=wallall2] if yearold<2011, cluster(stateid)

estimates save Data\Compiled\lgacallest, replace




**** Lg AC (GI weights)


quietly reg lgac MAafter MAduring MA after during  [aw=wallgi2] if yearold<2011, cluster(stateid)

estimates save Data\Compiled\lgacgiest, replace



**** Lg Prem (baseline weights)

quietly reg lgprem MAafter MAduring MA after during  [aw=wallall2] if yearold<2011, cluster(stateid)

estimates save Data\Compiled\lgpremallest, replace




**** Lg Prem (GI weights)

quietly reg lgprem MAafter MAduring MA after during  [aw=wallgi2] if yearold<2011, cluster(stateid)

estimates save Data\Compiled\lgpremgiest, replace




**** Coverage (baseline weights)

quietly reg mem_mo_ind_rel MAafter MAduring MA after during  [aw=wallall2] if yearold<2011, cluster(stateid)

estimates save Data\Compiled\covallest, replace


**** Coverage (GI weights)

quietly reg mem_mo_ind_rel MAafter MAduring MA after during  [aw=wallgi2] if yearold<2011, cluster(stateid)

estimates save Data\Compiled\covgiest, replace



**** save estimates 


*** baseline estimates

clear

estimates use Data\Compiled\covallest

matrix define para=e(b)

matrix para=[para[1,1..6]]'

matrix parall=para

matrix drop para

estimates use Data\Compiled\lgpremallest

matrix define para=e(b)

matrix para=[para[1,1..6]]'

matrix parall=parall,para

matrix drop para

estimates use Data\Compiled\lgacallest

matrix define para=e(b)

matrix para=[para[1,1..6]]'

matrix parall=parall,para

svmat parall

save  Data\Compiled\pointestbaseline.dta, replace


*** GI estimates

clear

estimates use Data\Compiled\covgiest

matrix define para=e(b)

matrix para=[para[1,1..6]]'

matrix parall=para

matrix drop para

estimates use Data\Compiled\lgpremgiest

matrix define para=e(b)

matrix para=[para[1,1..6]]'

matrix parall=parall,para

matrix drop para

estimates use Data\Compiled\lgacgiest

matrix define para=e(b)

matrix para=[para[1,1..6]]'

matrix parall=parall,para

svmat parall

save  Data\Compiled\pointestgi.dta, replace



eststo clear

clear all


*log close
